@@ -37,25 +37,41 @@ import json
 import textwrap
 from io import IOBase
 
-from hubzero.submit.LogMessage   import getLogIDMessage as getLogMessage, logSetMessageFile
-from hubzero.submit.SubmitClient import SubmitClient
+from hubzero.submit.ApplicationUtilities import ApplicationUtilities
+from hubzero.submit.LogMessage           import getLogIDMessage as getLogMessage, logSetMessageFile
+from hubzero.submit.SubmitClient         import SubmitClient
 
 class SubmitCommand:
-   LOGDIRECTORY = os.getcwd()
-   HUBLOGFILE   = '.submit.log'
-   HUBLOGPATH   = os.path.join(LOGDIRECTORY,HUBLOGFILE)
+   LOGDIRECTORY   = os.getcwd()
+   HUBLOGFILE     = '.submit.log'
+   HUBLOGPATH     = os.path.join(LOGDIRECTORY,HUBLOGFILE)
+   SUBMITLOGLEVEL = "ERROR"
 
    CONFIGURATIONDIRECTORY = os.path.join(os.sep,'etc','submit')
-   CONFIGURATIONFILE      = 'submit-client.conf'
+   CONFIGURATIONFILE      = "submit-client.conf"
 
    TAILNLINESDEFAULT = 10
    SEPARATORDEFAULT  = ","
 
    def __init__(self,
                 configurationDirectory=CONFIGURATIONDIRECTORY,
-                hubLogPath=HUBLOGPATH):
-      self.__openLogger(hubLogPath)
-      self.configFilePath = os.path.join(configurationDirectory,self.CONFIGURATIONFILE)
+                configurationFile=CONFIGURATIONFILE,
+                hubLogPath=HUBLOGPATH,
+                logLevel=SUBMITLOGLEVEL):
+      applicationUtilities = ApplicationUtilities(logLevel)
+
+      if sys.stderr.isatty():
+         applicationUtilities.openStreamLogger(sys.stderr,
+                                               logLevel)
+      else:
+         submitLogLocation = os.path.dirname(hubLogPath)
+         submitLogFilename = os.path.basename(hubLogPath)
+         applicationUtilities.openFileLogger(submitLogLocation,submitLogFilename,
+                                             logLevel)
+
+      self.logger = logging.getLogger(__name__)
+
+      self.configFilePath = os.path.join(configurationDirectory,configurationFile)
 
       try:
          instantiator          = traceback.extract_stack()[-2]
@@ -121,39 +137,6 @@ class SubmitCommand:
       self.stdin                = None
 
 
-   def __openLogger(self,
-                    hubLogPath):
-      class EmptyFilter(logging.Filter):
-         """
-         This is a filter which rejects empty messages
-
-         """
-
-         def filter(self,record):
-            if record.getMessage() == "":
-               emptyRecord = True
-            else:
-               emptyRecord = False
-
-            return(not emptyRecord)
-
-      self.logger = logging.getLogger('')
-      self.logger.setLevel(logging.ERROR)
-
-      if sys.stderr.isatty():
-         logHandler = logging.StreamHandler(sys.stderr)
-         logSetMessageFile(sys.stderr)
-      else:
-         logHandler = logging.FileHandler(hubLogPath)
-
-      emptyFilter = EmptyFilter()
-      logHandler.addFilter(emptyFilter)
-
-      logFormatter = logging.Formatter('%(asctime)s %(message)s','[%a %b %d %H:%M:%S %Y]')
-      logHandler.setFormatter(logFormatter)
-      self.logger.addHandler(logHandler)
-
-
    def __writeToStdout(self,
                        message):
       try:
@@ -2580,7 +2563,6 @@ class SubmitCommand:
             pass
          else:
             self.__show(textWidth=80)
-#           del self.args[showCommandIndex:showCommandIndex+1]
 
          result = self.submitClient.executeSubmission(self.instantiatorPath,
                                                       self.args)
